export { basicSetup, minimalSetup } from 'codemirror';

interface Extension {
}
interface Line {
    from: number;
    to: number;
    number: number;
    text: string;
    length: number;
}
interface Text {
    length: number;
    lines: number;
    lineAt(n: number): Line;
    replace(from: number, to: number, text: Text): Text;
    append(other: Text): Text;
    slice(from: number, to?: number): Text;
    sliceString(from: number, to?: number, lineSep?: string): string;
    eq(other: Text): boolean;
    toString(): string;
    toJSON(): string[];
}
interface EditorSelection {
    ranges: SelectionRange;
    mainIndex: number;
    main: SelectionRange;
    asSingle(): EditorSelection;
    addRange(range: SelectionRange, main?: boolean): EditorSelection;
    replaceRange(range: SelectionRange, which?: number): EditorSelection;
}
interface ChangeDesc {
    length: number;
    newLength: number;
    empty: boolean;
    invertedDesc: ChangeDesc;
    composeDesc(other: ChangeDesc): ChangeDesc;
}
interface SelectionRange {
    from: number;
    to: number;
    anchor: number;
    head: number;
    empty: boolean;
    assoc: -1 | 0 | 1;
    bidiLevel: number | null;
    goalColumn: number | undefined;
    map(change: ChangeDesc, assoc?: number): SelectionRange;
    extend(from: number, to?: number): SelectionRange;
    eq(other: SelectionRange, includeAssoc?: boolean): boolean;
}
interface EditorState {
    /**
     * The current document.
     */
    doc: Text;
    selection: EditorSelection;
    tabSize: number;
    lineBreak: string;
    readOnly: boolean;
    wordAt(pos: number): SelectionRange | null;
}
interface EditorStateConfig {
    doc?: string | Text;
    selection?: EditorSelection | {
        anchor: number;
        head?: number;
    };
    extensions?: Extension[];
}
interface EditorViewConfig extends EditorStateConfig {
    parent?: Element | DocumentFragment;
}
interface ChangeSet {
    from: number;
    insert: string;
}
interface Transaction {
    startState: EditorState;
    changes: ChangeSet | ChangeSet[];
    selection: EditorSelection | undefined;
    scrollIntoView: boolean;
    newDoc: Text;
    newSelection: EditorSelection;
    state: EditorState;
    docChanged: boolean;
    reconfigured: boolean;
    isUserEvent(event: string): boolean;
}
type ChangeSpec = {
    from: number;
    to?: number;
    insert?: string | Text;
} | ChangeSet | readonly ChangeSpec[];
interface TransactionSpec {
    changes?: ChangeSpec;
}
interface EditorView {
    state: EditorState;
    viewport: {
        from: number;
        to: number;
    };
    visibleRanges: readonly {
        from: number;
        to: number;
    }[];
    inView: boolean;
    composing: boolean;
    compositionStarted: boolean;
    root: DocumentOrShadowRoot;
    dom: HTMLElement;
    scrollDOM: HTMLElement;
    contentDOM: HTMLElement;
    dispatch(...specs: TransactionSpec[]): void;
    update(transactions: readonly Transaction[]): void;
    setState(newState: EditorState): void;
    themeClasses: string;
    documentTop: number;
    documentPadding: {
        top: number;
        bottom: number;
    };
    scaleX: number;
    scaleY: number;
    contentHeight: number;
    destroy(): void;
}
declare function createEditorView(config?: EditorViewConfig): EditorView;
interface StyleSpec {
}
declare function theme(spec: {
    [selector: string]: StyleSpec;
}, options?: {
    dark?: boolean;
}): Extension;
interface TagStyle {
}

export { type ChangeDesc, type ChangeSet, type ChangeSpec, type EditorSelection, type EditorState, type EditorStateConfig, type EditorView, type EditorViewConfig, type Extension, type Line, type SelectionRange, type StyleSpec, type TagStyle, type Text, type Transaction, type TransactionSpec, createEditorView, theme };
